import {styled} from '@mui/material/styles'
import zIndex from '@mui/material/styles/zIndex'
import SimpleMDE, {SimpleMDEReactProps, default as SimpleMDEDefault} from 'react-simplemde-editor'

const StyledMarkdownEditor = styled('div')(({theme}) => ({
  '& .editor-toolbar': {
    backgroundColor: theme.palette.background.paper,
    borderColor: theme.palette.divider,
  },
  '& .editor-toolbar button': {
    color: theme.palette.text.primary,
  },
  '& .editor-toolbar button:hover': {
    backgroundColor: theme.palette.action.hover,
  },
  '& .editor-toolbar button:active, & .editor-toolbar button.active': {
    backgroundColor: theme.palette.action.selected,
  },
  '& .editor-statusbar': {
    display: 'none',
  },
  // Стили для самого редактора
  '& .CodeMirror': {
    backgroundColor: theme.palette.background.paper,
    color: theme.palette.text.primary,
    borderColor: theme.palette.divider,
  },
  // Стили для текста в редакторе
  '& .CodeMirror-selected': {
    backgroundColor: `${theme.palette.action.selected} !important`,
  },
  '& .CodeMirror-cursor': {
    borderLeftColor: theme.palette.text.primary,
  },
  // Стили для markdown разметки
  '& .cm-header': {
    color: theme.palette.primary.main,
  },
  '& .cm-quote': {
    color: theme.palette.text.secondary,
    fontStyle: 'italic',
  },
  '& .cm-link': {
    color: theme.palette.primary.main,
  },
  '& .cm-url': {
    color: theme.palette.secondary.main,
  },
  '& .cm-formatting': {
    color: theme.palette.text.secondary,
  },

  '& .CodeMirror .editor-preview-full': {
    backgroundColor: theme.palette.background.paper,
    color: theme.palette.text.primary,
    borderColor: theme.palette.divider,
  },

  '& .EasyMDEContainer': {
    position: 'relative',
    zIndex: zIndex.modal,
  },
  '& .guide': {
    display: 'none',
  },
}));

export const MarkdownEditor = (props: SimpleMDEReactProps) => {
  if(props.options)
    props.options.toolbar = [
      "bold",
      "italic",
      "strikethrough",
      {
        name: "Underline",
        action: (editor: any) => {

          const cm = editor.codemirror;
          let output = '';
          const selectedText = cm.getSelection();
          const text = selectedText ?? 'placeholder';
        
          output = '<u>' + text + '</u>';
          cm.replaceSelection(output);
        
        },
        className: "fa fa-underline", // Look for a suitable icon
        title: "Underline (Ctrl/Cmd-Alt-U)",
      },
      "heading",
      "quote",
      "unordered-list",
      "ordered-list",
      "link",
      "image",
      "code",
      "table",
      "horizontal-rule",
      "preview",
      "fullscreen",
      "guide"
    ]
  return (
    <StyledMarkdownEditor className="my-markdown-editor" sx={{marginTop: 1.5, marginBottom: 3}}>
      <SimpleMDE {...props}/>
    </StyledMarkdownEditor>
  )
}
