import { Box } from "@mui/material";
import { Languages, languageStore } from "@stores";
import { observer } from "mobx-react-lite";


export const LanguageSelector = observer(({
  action
}: {action?: (lang: Languages) => void}) => {
	const { language, setLanguageAction } = languageStore;

  function handleLanguageChange(language: Languages) {
    if(action) action(language);
    else setLanguageAction(language);
  }
  
  return (
    <Box
      sx={{
        display: "flex",
        gap: 2,
        height: "min-content"
      }}
    >
      <Box
        sx={{
          cursor: "pointer",
          flex: 1,
          display: "flex",
          justifyContent: "center",
          bgcolor: language === "ru" ? "primary.main" : "transparent",
          color: language === "ru" ? "white" : "inherit",
          borderRadius: 1,
          p: 1,
        }}
        onClick={() => handleLanguageChange("ru")}
      >
        RU
      </Box>
      <Box
        sx={{
          cursor: "pointer",
          flex: 1,
          display: "flex",
          justifyContent: "center",
          bgcolor: language === "en" ? "primary.main" : "transparent",
          color: language === "en" ? "white" : "inherit",
          borderRadius: 1,
          p: 1,
        }}
        onClick={() => handleLanguageChange("en")}
      >
        EN
      </Box>
      <Box
        sx={{
          cursor: "pointer",
          flex: 1,
          display: "flex",
          justifyContent: "center",
          bgcolor: language === "zh" ? "primary.main" : "transparent",
          color: language === "zh" ? "white" : "inherit",
          borderRadius: 1,
          p: 1,
        }}
        onClick={() => handleLanguageChange("zh")}
      >
        ZH
      </Box>
    </Box>
  );
});
