import { type GridColDef } from "@mui/x-data-grid";
import { CustomDataGrid } from "../../components/CustomDataGrid";
import {
  DeleteButton,
  EditButton,
  List,
  ShowButton,
  useDataGrid,
} from "@refinedev/mui";
import React from "react";
import { observer } from "mobx-react-lite";
import { cityStore } from "../../store/CityStore";
import { languageStore } from "../../store/LanguageStore";

export const CarrierList = observer(() => {
  const { city_id } = cityStore;
  const { language } = languageStore;

  const { dataGridProps } = useDataGrid({
    resource: "carrier",
    meta: {
      headers: {
        "Accept-Language": language,
      },
    },
    filters: {
      permanent: [
        {
          field: "cityID",
          operator: "eq",
          value: city_id === "0" ? null : city_id,
        },
      ],
    },
  });

  const columns = React.useMemo<GridColDef[]>(
    () => [
      {
        field: "id",
        headerName: "ID",
        type: "number",
        minWidth: 50,
        align: "left",
        headerAlign: "left",
      },
      {
        field: "city_id",
        headerName: "ID Города",
        type: "number",
        minWidth: 100,
        align: "left",
        headerAlign: "left",
      },
      {
        field: "full_name",
        headerName: "Полное имя",
        type: "string",
        minWidth: 200,
      },
      {
        field: "short_name",
        headerName: "Короткое имя",
        type: "string",
        minWidth: 125,
      },
      {
        field: "city",
        headerName: "Город",
        type: "string",
        minWidth: 125,
        align: "left",
        headerAlign: "left",
        flex: 1,
      },
      {
        field: "main_color",
        headerName: "Основной цвет",
        type: "string",
        minWidth: 150,
        renderCell: ({ value }) => (
          <div
            style={{
              display: "grid",
              placeItems: "center",
              width: "100%",
              height: "100%",
              backgroundColor: `${value}10`,
              borderRadius: 10,
            }}
          >
            {value}
          </div>
        ),
      },
      {
        field: "left_color",
        headerName: "Цвет левого виджета",
        type: "string",
        minWidth: 150,
        renderCell: ({ value }) => (
          <div
            style={{
              display: "grid",
              placeItems: "center",
              width: "100%",
              height: "100%",
              backgroundColor: `${value}10`,
              borderRadius: 10,
            }}
          >
            {value}
          </div>
        ),
      },
      {
        field: "right_color",
        headerName: "Цвет правого виджета",
        type: "string",
        minWidth: 150,
        renderCell: ({ value }) => (
          <div
            style={{
              display: "grid",
              placeItems: "center",
              width: "100%",
              height: "100%",
              backgroundColor: `${value}10`,
              borderRadius: 10,
            }}
          >
            {value}
          </div>
        ),
      },
      {
        field: "logo",
        headerName: "Лого",
        type: "string",
        minWidth: 150,
      },
      {
        field: "slogan",
        headerName: "Слоган",
        type: "string",
        minWidth: 150,
      },
      {
        field: "actions",
        headerName: "Действия",
        minWidth: 120,
        display: "flex",
        align: "right",
        headerAlign: "center",
        sortable: false,
        filterable: false,
        disableColumnMenu: true,
        renderCell: function render({ row }) {
          return (
            <>
              <EditButton hideText recordItemId={row.id} />
              <ShowButton hideText recordItemId={row.id} />
              <DeleteButton
                hideText
                confirmTitle="Вы уверены?"
                recordItemId={row.id}
              />
            </>
          );
        },
      },
    ],
    []
  );

  return (
    <List>
      <CustomDataGrid {...dataGridProps} languageEnabled columns={columns} />
    </List>
  );
});
