import { VEHICLE_TYPES } from "../../lib/constants";

export type StationItem = {
  id: number;
  name: string;
  description: string;
  offset_x: number;
  offset_y: number;
  [key: string]: string | number;
};

export type VehicleItem = {
  id: number;
  tail_number: number;
  type: number;
  [key: string]: string | number;
};

export type SightItem = {
  id: number;
  name: string;
  city: string;
  city_id: number;
  address: string;
  [key: string]: string | number;
};

export type FieldType<T> = {
  label: string;
  data: keyof T;
  render?: (value: any) => React.ReactNode;
};

export const stationFields: Array<FieldType<StationItem>> = [
  { label: "Название", data: "name" },
  { label: "Описание", data: "description" },
];

export const sightFields: Array<FieldType<SightItem>> = [
  { label: "Название", data: "name" },
  { label: "Город", data: "city" },
  { label: "Адрес", data: "address" },
];

export const vehicleFields: Array<FieldType<VehicleItem>> = [
  { label: "Бортовой номер", data: "tail_number" },
  {
    label: "Тип",
    data: "type",
    render: (value: number) =>
      VEHICLE_TYPES.find((type) => type.value === value)?.label || value,
  },
];
